@@ -13,6 +13,7 @@ class permission_manager {
     private $page_permissions = array(
         'dashboard' => array('all'), // All authenticated users
         'database-management' => array('all'), // All authenticated users
+        'postgresql-management' => array('all'), // All authenticated users
         'user-management' => array('root'), // Only root
         'security-management' => array('root'), // Only root
         'announcements-management' => array('root'), // Only root
@@ -34,6 +35,7 @@ class permission_manager {
     private $api_permissions = array(
         'user-management' => array('root'),
         'database-management' => array('all'),
+        'postgresql-management' => array('all'),
         'security-management' => array('root'),
         'announcements-management' => array('root'),
         'update-management' => array('root'),
